`ensembleObsLabels.ensembleData` <-
function (x) 
{
 dimnames(x)[[1]]
}

